@@ -2,11 +2,11 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
-library test.analysis.reanalyze;
-
-import 'package:analysis_server/plugin/protocol/protocol.dart';
+import 'package:analysis_server/protocol/protocol.dart';
+import 'package:analysis_server/protocol/protocol_generated.dart';
 import 'package:analysis_server/src/constants.dart';
 import 'package:analyzer/src/generated/engine.dart';
+import 'package:analyzer_plugin/protocol/protocol_common.dart';
 import 'package:test/test.dart';
 import 'package:test_reflective_loader/test_reflective_loader.dart';
 
@@ -22,6 +22,9 @@ main() {
 class ReanalyzeTest extends AbstractAnalysisTest {
   Map<String, List<AnalysisError>> filesErrors = {};
 
+  @override
+  bool get enableNewAnalysisDriver => false;
+
   @override
   void processNotification(Notification notification) {
     if (notification.event == ANALYSIS_ERRORS) {
@@ -72,4 +75,13 @@ class ReanalyzeTest extends AbstractAnalysisTest {
       expect(errors, hasLength(1));
     }
   }
+
+  test_sentToPlugins() async {
+    createProject();
+    await waitForTasksFinished();
+    Request request = new Request("0", ANALYSIS_REANALYZE);
+    handleSuccessfulRequest(request);
+    // verify
+    expect(pluginManager.broadcastedRequest, isNotNull);
+  }
 }
