@@ -5,8 +5,6 @@
 /**
  * Code generation for the file "AnalysisServer.java".
  */
-library java.generator.server;
-
 import 'package:analyzer/src/codegen/tools.dart';
 import 'package:front_end/src/codegen/tools.dart';
 
@@ -118,6 +116,9 @@ class CodegenAnalysisServer extends CodegenJavaVisitor {
         toHtmlVisitor.write('{@code ${request.longMethod }}');
         toHtmlVisitor.translateHtml(request.html);
         toHtmlVisitor.javadocParams(request.params);
+        if (request.deprecated) {
+          toHtmlVisitor.p(() => toHtmlVisitor.write('@deprecated'));
+        }
       }));
       write('public void $methodName(');
       List<String> arguments = [];
