@@ -8,11 +8,9 @@ import 'dart:async';
 import 'dart:collection';
 
 import 'package:analyzer/dart/ast/ast.dart';
-import 'package:analyzer/dart/ast/standard_resolution_map.dart';
 import 'package:analyzer/dart/element/element.dart';
 import 'package:analyzer/error/error.dart';
 import 'package:analyzer/exception/exception.dart';
-import 'package:analyzer/instrumentation/instrumentation.dart';
 import 'package:analyzer/plugin/resolver_provider.dart';
 import 'package:analyzer/plugin/task.dart';
 import 'package:analyzer/src/cancelable_future.dart';
@@ -21,7 +19,6 @@ import 'package:analyzer/src/context/cache.dart';
 import 'package:analyzer/src/dart/element/element.dart';
 import 'package:analyzer/src/generated/constant.dart';
 import 'package:analyzer/src/generated/engine.dart';
-import 'package:analyzer/src/generated/incremental_resolver.dart';
 import 'package:analyzer/src/generated/resolver.dart';
 import 'package:analyzer/src/generated/sdk.dart' show DartSdk;
 import 'package:analyzer/src/generated/source.dart';
@@ -29,7 +26,6 @@ import 'package:analyzer/src/generated/utilities_collection.dart';
 import 'package:analyzer/src/task/dart.dart';
 import 'package:analyzer/src/task/dart_work_manager.dart';
 import 'package:analyzer/src/task/driver.dart';
-import 'package:analyzer/src/task/incremental_element_builder.dart';
 import 'package:analyzer/src/task/manager.dart';
 import 'package:analyzer/task/dart.dart';
 import 'package:analyzer/task/general.dart';
@@ -56,16 +52,6 @@ typedef T PendingFutureComputer<T>(CacheEntry entry);
  * An [AnalysisContext] in which analysis can be performed.
  */
 class AnalysisContextImpl implements InternalAnalysisContext {
-  /**
-   * The next context identifier.
-   */
-  static int _NEXT_ID = 0;
-
-  /**
-   * The unique identifier of this context.
-   */
-  final int _id = _NEXT_ID++;
-
   /**
    * The flag that is `true` if the context is being analyzed.
    */
@@ -337,7 +323,6 @@ class AnalysisContextImpl implements InternalAnalysisContext {
     this._options.strongMode = options.strongMode;
     this._options.trackCacheDependencies = options.trackCacheDependencies;
     this._options.disableCacheFlushing = options.disableCacheFlushing;
-    this._options.finerGrainedInvalidation = options.finerGrainedInvalidation;
     this._options.patchPaths = options.patchPaths;
     if (options is AnalysisOptionsImpl) {
       this._options.strongModeHints = options.strongModeHints;
@@ -1072,12 +1057,9 @@ class AnalysisContextImpl implements InternalAnalysisContext {
     if (newContents != null) {
       if (changed) {
         entry.modificationTime = _contentCache.getModificationStamp(source);
-        if (!analysisOptions.incremental ||
-            !_tryPoorMansIncrementalResolution(source, newContents)) {
-          // Don't compare with old contents because the cache has already been
-          // updated, and we know at this point that it changed.
-          _sourceChanged(source, compareWithOld: false);
-        }
+        // Don't compare with old contents because the cache has already been
+        // updated, and we know at this point that it changed.
+        _sourceChanged(source, compareWithOld: false);
         entry.setValue(CONTENT, newContents, TargetedResult.EMPTY_LIST);
       } else {
         entry.modificationTime = _contentCache.getModificationStamp(source);
@@ -1097,9 +1079,7 @@ class AnalysisContextImpl implements InternalAnalysisContext {
       // If not the same content (e.g. the file is being closed without save),
       // then force analysis.
       if (changed) {
-        if (newContents == null ||
-            !analysisOptions.incremental ||
-            !_tryPoorMansIncrementalResolution(source, newContents)) {
+        if (newContents == null) {
           _sourceChanged(source);
         }
       }
@@ -1529,30 +1509,6 @@ class AnalysisContextImpl implements InternalAnalysisContext {
     return notices;
   }
 
-  /**
-   * Return a [CompilationUnit] for the given library and unit sources, which
-   * can be incrementally resolved.
-   */
-  CompilationUnit _getIncrementallyResolvableUnit(
-      Source librarySource, Source unitSource) {
-    LibrarySpecificUnit target =
-        new LibrarySpecificUnit(librarySource, unitSource);
-    for (ResultDescriptor<CompilationUnit> result in [
-      RESOLVED_UNIT,
-      RESOLVED_UNIT12,
-      RESOLVED_UNIT11,
-      RESOLVED_UNIT10,
-      RESOLVED_UNIT9,
-      RESOLVED_UNIT8
-    ]) {
-      CompilationUnit unit = getResult(target, result);
-      if (unit != null) {
-        return unit;
-      }
-    }
-    return null;
-  }
-
   /**
    * Return a list containing all of the sources known to this context that have
    * the given [kind].
@@ -1841,53 +1797,6 @@ class AnalysisContextImpl implements InternalAnalysisContext {
 
     // We need to invalidate the cache.
     {
-      if (analysisOptions.finerGrainedInvalidation &&
-          AnalysisEngine.isDartFileName(source.fullName)) {
-        // TODO(scheglov) Incorrect implementation in general.
-        entry.setState(TOKEN_STREAM, CacheState.FLUSHED);
-        entry.setState(PARSED_UNIT, CacheState.FLUSHED);
-        SourceKind sourceKind = getKindOf(source);
-        List<Source> partSources = getResult(source, INCLUDED_PARTS);
-        if (sourceKind == SourceKind.LIBRARY && partSources.isEmpty) {
-          Source librarySource = source;
-          // Try to find an old unit which has element model.
-          CacheEntry unitEntry =
-              getCacheEntry(new LibrarySpecificUnit(librarySource, source));
-          CompilationUnit oldUnit = RESOLVED_UNIT_RESULTS
-              .skipWhile((result) => result != RESOLVED_UNIT2)
-              .map(unitEntry.getValue)
-              .firstWhere((unit) => unit != null, orElse: () => null);
-          // If we have the old unit, we can try to update it.
-          if (oldUnit != null) {
-            // Safely parse the source.
-            CompilationUnit newUnit;
-            try {
-              newUnit = parseCompilationUnit(source);
-            } catch (_) {
-              // The source might have been removed by this time.
-              // We cannot perform incremental invalidation.
-            }
-            // If the new unit was parsed successfully, continue.
-            if (newUnit != null) {
-              IncrementalCompilationUnitElementBuilder builder =
-                  new IncrementalCompilationUnitElementBuilder(
-                      oldUnit, newUnit);
-              builder.build();
-              CompilationUnitElementDelta unitDelta = builder.unitDelta;
-              if (!unitDelta.hasDirectiveChange) {
-                unitEntry.setValueIncremental(
-                    COMPILATION_UNIT_CONSTANTS, builder.unitConstants, false);
-                DartDelta dartDelta = new DartDelta(source);
-                unitDelta.addedDeclarations.forEach(dartDelta.elementChanged);
-                unitDelta.removedDeclarations.forEach(dartDelta.elementChanged);
-                unitDelta.classDeltas.values.forEach(dartDelta.classChanged);
-                entry.setState(CONTENT, CacheState.INVALID, delta: dartDelta);
-                return;
-              }
-            }
-          }
-        }
-      }
       entry.setState(CONTENT, CacheState.INVALID);
       entry.setState(MODIFICATION_TIME, CacheState.INVALID);
       entry.setState(SOURCE_KIND, CacheState.INVALID);
@@ -1907,81 +1816,6 @@ class AnalysisContextImpl implements InternalAnalysisContext {
     _removeFromPriorityOrder(source);
   }
 
-  /**
-   * TODO(scheglov) A hackish, limited incremental resolution implementation.
-   */
-  bool _tryPoorMansIncrementalResolution(Source unitSource, String newCode) {
-    return PerformanceStatistics.incrementalAnalysis.makeCurrentWhile(() {
-      incrementalResolutionValidation_lastUnitSource = null;
-      incrementalResolutionValidation_lastLibrarySource = null;
-      incrementalResolutionValidation_lastUnit = null;
-      // prepare the source entry
-      CacheEntry sourceEntry = _cache.get(unitSource);
-      if (sourceEntry == null) {
-        return false;
-      }
-      // prepare the (only) library source
-      List<Source> librarySources = getLibrariesContaining(unitSource);
-      if (librarySources.length != 1) {
-        return false;
-      }
-      Source librarySource = librarySources[0];
-      // prepare the unit entry
-      CacheEntry unitEntry =
-          _cache.get(new LibrarySpecificUnit(librarySource, unitSource));
-      if (unitEntry == null) {
-        return false;
-      }
-      // prepare the existing unit
-      CompilationUnit oldUnit =
-          _getIncrementallyResolvableUnit(librarySource, unitSource);
-      if (oldUnit == null) {
-        return false;
-      }
-      // do resolution
-      Stopwatch perfCounter = new Stopwatch()..start();
-      PoorMansIncrementalResolver resolver = new PoorMansIncrementalResolver(
-          typeProvider,
-          unitSource,
-          _cache,
-          sourceEntry,
-          unitEntry,
-          oldUnit,
-          analysisOptions.incrementalApi);
-      bool success = resolver.resolve(newCode);
-      AnalysisEngine.instance.instrumentationService.logPerformance(
-          AnalysisPerformanceKind.INCREMENTAL,
-          perfCounter,
-          'success=$success,context_id=$_id,code_length=${newCode.length}');
-      if (!success) {
-        return false;
-      }
-      // if validation, remember the result, but throw it away
-      if (analysisOptions.incrementalValidation) {
-        CompilationUnitElement compilationUnitElement =
-            resolutionMap.elementDeclaredByCompilationUnit(oldUnit);
-        incrementalResolutionValidation_lastUnitSource =
-            compilationUnitElement.source;
-        incrementalResolutionValidation_lastLibrarySource =
-            compilationUnitElement.library.source;
-        incrementalResolutionValidation_lastUnit = oldUnit;
-        return false;
-      }
-      // prepare notice
-      {
-        ChangeNoticeImpl notice = getNotice(unitSource);
-        notice.resolvedDartUnit = oldUnit;
-        AnalysisErrorInfo errorInfo = getErrors(unitSource);
-        notice.setErrors(errorInfo.errors, errorInfo.lineInfo);
-      }
-      // schedule
-      dartWorkManager.unitIncrementallyResolved(librarySource, unitSource);
-      // OK
-      driver.reset();
-      return true;
-    });
-  }
-
   static bool _samePatchPaths(
       Map<String, List<String>> a, Map<String, List<String>> b) {
     if (a.length != b.length) return false;
