@@ -7,7 +7,7 @@ library analyzer.test.source.test_all;
 import 'package:test_reflective_loader/test_reflective_loader.dart';
 
 import 'analysis_options_provider_test.dart' as analysis_options_provider_test;
-import 'embedder_test.dart' as embedder_test;
+import 'embedder_test.dart' as embedder_test; // ignore: deprecated_member_use
 import 'error_processor_test.dart' as error_processor_test;
 import 'package_map_provider_test.dart' as package_map_provider_test;
 import 'package_map_resolver_test.dart' as package_map_resolver_test;
