@@ -6,7 +6,6 @@ library analyzer.test.src.dart.analysis.test_all;
 
 import 'package:test_reflective_loader/test_reflective_loader.dart';
 
-import 'byte_store_test.dart' as byte_store;
 import 'driver_test.dart' as driver;
 import 'file_state_test.dart' as file_state;
 import 'index_test.dart' as index;
@@ -16,7 +15,6 @@ import 'search_test.dart' as search_test;
 /// Utility for manually running all tests.
 main() {
   defineReflectiveSuite(() {
-    byte_store.main();
     driver.main();
     file_state.main();
     index.main();
