@@ -6,12 +6,13 @@ library fasta.parser.listener;
 
 import '../fasta_codes.dart' show FastaMessage;
 
-import '../scanner/token.dart' show BeginGroupToken, SymbolToken, Token;
+import '../../scanner/token.dart' show Token, TokenType;
+
+import '../scanner/token.dart' show BeginGroupToken, SymbolToken;
 
 import '../util/link.dart' show Link;
 
-import 'package:front_end/src/fasta/scanner/precedence.dart' show RECOVERY_INFO;
-import 'parser.dart' show FormalParameterType;
+import 'parser.dart' show FormalParameterType, MemberKind;
 
 import 'identifier_context.dart' show IdentifierContext;
 
@@ -64,6 +65,12 @@ class Listener {
     logEvent("Cascade");
   }
 
+  void beginCaseExpression(Token caseKeyword) {}
+
+  void endCaseExpression(Token colon) {
+    // logEvent("CaseExpression");
+  }
+
   void beginClassBody(Token token) {}
 
   /// Handle the end of the body of a class declaration.  The only substructures
@@ -104,6 +111,12 @@ class Listener {
     logEvent("CompilationUnit");
   }
 
+  void beginConstLiteral(Token token) {}
+
+  void endConstLiteral(Token token) {
+    logEvent("ConstLiteral");
+  }
+
   void beginConstructorReference(Token start) {}
 
   void endConstructorReference(
@@ -173,20 +186,21 @@ class Listener {
     logEvent("FactoryMethod");
   }
 
-  void beginFormalParameter(Token token) {}
+  void beginFormalParameter(Token token, MemberKind kind) {}
 
-  void endFormalParameter(Token covariantKeyword, Token thisKeyword,
-      Token nameToken, FormalParameterType kind) {
+  void endFormalParameter(Token thisKeyword, Token nameToken,
+      FormalParameterType kind, MemberKind memberKind) {
     logEvent("FormalParameter");
   }
 
-  void handleNoFormalParameters(Token token) {
+  void handleNoFormalParameters(Token token, MemberKind kind) {
     logEvent("NoFormalParameters");
   }
 
-  void beginFormalParameters(Token token) {}
+  void beginFormalParameters(Token token, MemberKind kind) {}
 
-  void endFormalParameters(int count, Token beginToken, Token endToken) {
+  void endFormalParameters(
+      int count, Token beginToken, Token endToken, MemberKind kind) {
     logEvent("FormalParameters");
   }
 
@@ -197,8 +211,7 @@ class Listener {
   /// - Variable declarations (count times)
   ///
   /// Doesn't have a corresponding begin event, use [beginMember] instead.
-  void endFields(
-      int count, Token covariantKeyword, Token beginToken, Token endToken) {
+  void endFields(int count, Token beginToken, Token endToken) {
     logEvent("Fields");
   }
 
@@ -409,7 +422,7 @@ class Listener {
 
   /// Handle the end of a field initializer.  Substructures:
   /// - Initializer expression
-  void endFieldInitializer(Token assignment) {
+  void endFieldInitializer(Token assignment, Token token) {
     logEvent("FieldInitializer");
   }
 
@@ -641,7 +654,7 @@ class Listener {
 
   void beginRethrowStatement(Token token) {}
 
-  void endRethrowStatement(Token throwToken, Token endToken) {
+  void endRethrowStatement(Token rethrowToken, Token endToken) {
     logEvent("RethrowStatement");
   }
 
@@ -808,7 +821,7 @@ class Listener {
   /// - type parameters
   /// - formal parameters
   void endFunctionTypedFormalParameter(
-      Token covariantKeyword, Token thisKeyword, FormalParameterType kind) {
+      Token thisKeyword, FormalParameterType kind) {
     logEvent("FunctionTypedFormalParameter");
   }
 
@@ -1022,12 +1035,39 @@ class Listener {
     logEvent("Script");
   }
 
+  /// Matches a generic comment type substitution and injects it into the token
+  /// stream before the given [token].
+  Token injectGenericCommentTypeAssign(Token token) {
+    return token;
+  }
+
+  /// Matches a generic comment type parameters or type arguments and injects
+  /// them into the token stream before the given [token].
+  Token injectGenericCommentTypeList(Token token) {
+    return token;
+  }
+
+  /// If the [tokenWithComment] has a type substitution comment /*=T*/, then
+  /// the comment should be scanned into new tokens, and these tokens inserted
+  /// instead of tokens from the [tokenToStartReplacing] to the
+  /// [tokenWithComment]. Returns the first newly inserted token, or the
+  /// original [tokenWithComment].
+  Token replaceTokenWithGenericCommentTypeAssign(
+      Token tokenToStartReplacing, Token tokenWithComment) {
+    return tokenToStartReplacing;
+  }
+
+  /// A type has been just parsed, and the parser noticed that the next token
+  /// has a type substitution comment /*=T*. So, the type that has been just
+  /// parsed should be discarded, and a new type should be parsed instead.
+  void discardTypeReplacedWithCommentTypeAssign() {}
+
   /// Creates a new synthetic token whose `next` pointer points to [next].
   ///
   /// If [next] is `null`, `null` is returned.
   Token newSyntheticToken(Token next) {
     if (next == null) return null;
-    return new SymbolToken(RECOVERY_INFO, next.charOffset)..next = next;
+    return new SymbolToken(TokenType.RECOVERY, next.charOffset)..next = next;
   }
 }
 
